package
Version:
v0.0.0-...-de84516
Opens a new window with list of versions in this module.
Published: Feb 25, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func NewWC(filenames []string, printLine, printWord, printChar, printByte bool) *WC
Source Files
¶
Click to show internal directories.
Click to hide internal directories.